Severity

Enum Severity 

pub enum Severity {
    Default,
    Debug,
    Info,
    Notice,
    Warning,
    Error,
    Critical,
    Alert,
    Emergency,
}
Allows using any severity value supported by Cloud Logging.

Use like:

use tracing_google_cloud::Severity;

tracing::debug!(severity = %Severity::Debug, "message");
tracing::info!(severity = %Severity::Info, "information");
tracing::info!(severity = %Severity::Notice, "hmm notice");
tracing::warn!(severity = %Severity::Warning, "a scary warning!");
tracing::error!(severity = %Severity::Error, "something is wrong");

// these are only available as Severity enums:
tracing::error!(severity = %Severity::Critical, "critical error!");
tracing::error!(severity = %Severity::Alert, "oh no!");
tracing::error!(severity = %Severity::Emergency, "this service is on fire now");

The tracing level is ignored by this crate when using the severity field.

Variants



Default



Debug



Info



Notice



Warning



Error



Critical



Alert



Emergency