pub struct InvalidSeverity(/* private fields */);Expand description
A severity value was not one of the allowed enumerations.
If you’re getting this error, you’re probably not using the values contained in Severity. See those docs for an example.
If you are doing this correctly and this is still failing, it’s probably a bug.