LayerBuilder

Struct LayerBuilder 

pub struct LayerBuilder<ProjectId = (), W: Write = Stdout> { /* private fields */ }

Implementations

Source

impl<W: Write> LayerBuilder<(), W>

pub fn with_project_id<T: AsRef<str>>(self, text: T) -> LayerBuilder<T, W>

Sets the project’s ID for use by the Layer. This is mainly useful for including trace IDs, where, depending on the writer you’re using, Google Cloud may not be able to infer the correct project ID. To (hopefully) get around this if it is ever a problem, this crate always writes traces in the full format, projects/<...>/traces/<...>.

As such, the project ID is required.

If the opentelemetry feature is disabled, it is allowed to construct the layer without calling this function.

Source

impl<ProjectId, W: Write> LayerBuilder<ProjectId, W>

pub fn with_writer<N: Write>(self, writer: N) -> LayerBuilder<ProjectId, N>

Sets the writer which logs will be written to. The default is std::io::stdout().

Source

impl<ProjectId: ProjectIdTrait, W: Write> LayerBuilder<ProjectId, W>

pub fn build(self) -> Layer<W>